# Sitecore PackageManagementService Azure deployment guide

## Prerequisites

You need to change execution policy in powershell to allow you run unsigned scripts on local computer, to do it run powershell with administrator rights and execute this line in powershell console: 

```
    Set-ExecutionPolicy RemoteSigned
```

Then, you need to install Azure powershell modules by executing this line in powershell console:

```
    Install-Module AzureRM
```

 Note: If you want to specify powershell repository you should set addition parameter to this command `-Repository "repository name"`

## Necessary steps for deployment

### Register Azure application

Before executing deployment script you need to set up Azure AD application. You can do it by the following steps:
- Navigate to [Azure portal](https://portal.azure.com/)
- Go to the `Azure Active Directory` tab
- Click on the `App registrations` button
- In the top of `App registrations` window click on the `+ New application registration` button
- Fill the parameters in the opened `Create` window:
    - Name: any
    - Application type: Web app / API
    - Sign-on URL: any

### Set Azure application permissions

 When the new application is created, you need to add the application to the `Contributor` role of the subscription by following steps:
- Navigate to [Azure portal](https://portal.azure.com/)
- Click on the your profile button in the top right corner of the window
- In dropdown list, select `My permissions`
- In the `Subscription` drop-down select your subscription
- Click on the `Click here to view complete access details for this subscription.` link
- On the opened `Access control (IAM)` tab press `Add` button
- In the `Add permissions` panel: 
    - In `Role` dropdown select `Contributor` role
    - In `Assign access to` dropdown select `azure AD user, group, or application`
    - In `Select` dropdown select application you've created
    - Click `Save` button

### Prepare deployment parameters

For the deployment, you need to get the following values on [Azure portal](https://portal.azure.com/):

1. Azure subscription ID
    - In the search box type subscriptions
    - Select `Subscriptions` from the search results
    - Find your appropriate subscription and copy `Subscription ID` value
2. Azure tenant id
    - Navigate to `Azure Active Directory`
    - Click `Properties` button
    - Copy `Directory ID` value
3.	Azure client id
    - Navigate to `Azure Active Directory`
    - Open `App Registrations` tab
    - Select your application
    - Copy `Application ID` value
4.	Azure security key
    - Navigate to `Azure Active Directory`
    - Open `App Registrations` tab
    - Select your application
    - Click on the `Settings` button
    - In the `Settings` window click `Keys` button.
    - In the opened `Keys` window, you can create key that will allow you deploy services to Azure without entering your credentials every time (copy generated value because you won't be able to see it after closing tab)

### Package Management Service deliverables

#### PackageManagementServicePackage.[ver].rev-[rev].wdp.zip

This is a WDP you need to use for application deployment. It contains all files of Package Management Service application.

### PackageManagementServicePackage.[ver].rev-[rev].azure-deployment-guide.zip

The archive contains all that you need for service deployment in Azure.
In the archive you can find following content: 

```
    Deployment guide
    Templates folder with ARM templates for storage and web app deployment
    AzureDeploy.ps1 deployment script
```

### Set deployment parameters

After unpacking, you need to modify deployment parameters:
- go to templates folder:
    1. ``serviceDeploy.parameters.json`` file, you need to change "webAppName" to your unique web app name
    2. ``storageDeploy.parameters.json`` file, you need to change "name" parameter to your unique storage account name
-  find in folder on upper level ``AzureDeploy.ps1`` file, change:
    1. ``$resourceGroupName =  "sitecorepackagemanagamentservice"`` to your  resource group name
    2. ``$storageContainerName = "packagemanagementservicestorage"`` to your unique storage container name
    3. ``$resourceGroupLocation = "North Europe"`` to your pref resource group location (can be left as it is)

### Start deployment

Then you need to open Powershell console with admin rights and navigate to folder with unpacked archive and execute next line: 

```
    .\AzureDeploy.ps1 
    –subscriptionId  [your value] 
    -wdpPackagePath [your value] 
    –azureSecurityKey [your value] 
    –azureClientID [your value] 
    –azureTenantID [your value]
```

Note: `wdpPackagePath` parameter should include the filename of the WDP zip, for example `C:\deployment-package\PackageManagementServicePackage.x.y.z.rev-ddmmyy.azure-wdp.zip`

## References
* [How to get Azure subscription ID](https://blogs.msdn.microsoft.com/mschray/2016/03/18/getting-your-azure-subscription-guid-new-portal/)
* [How to register Azure AD application](https://docs.microsoft.com/en-us/azure/azure-resource-manager/resource-group-create-service-principal-portal#create-an-azure-active-directory-application)
* [How to get application ID and authentication key](https://docs.microsoft.com/en-gb/azure/azure-resource-manager/resource-group-create-service-principal-portal#get-application-id-and-authentication-key)
* [How to get tenant ID](https://docs.microsoft.com/en-gb/azure/azure-resource-manager/resource-group-create-service-principal-portal#get-tenant-id)
* [How to assign application to role](https://docs.microsoft.com/en-gb/azure/azure-resource-manager/resource-group-create-service-principal-portal#assign-application-to-role)