# Iterates over all nodes and finds the node with the same key as the passed etalon node
Function Find-MatchingReSharperSettingNode($allNodes, $etalonNode) {
    $keyAttrName = "Key"
    $keyAttrNs = "http://schemas.microsoft.com/winfx/2006/xaml"

    # In order to identify the matching node we use the Key attribute value.
    # Attribute belongs to the special namespace, so we should specify that namespace.
    $etalonKey = $etalonNode.GetAttribute($keyAttrName, $keyAttrNs)

    # Iterate over all nodes and find node with the same key.
    foreach ($node in $allNodes) {
        $nodeKey = $node.GetAttribute($keyAttrName, $keyAttrNs)

        if($nodeKey -eq $etalonKey) {
            return $node
        }
    }

    # Return null if a matching node is not present.
    return $null
}

# Return the root node that holds all the setting entries
Function Get-ReSharperSettingsRootNode($doc) {
    return $doc.ResourceDictionary
}

# Return all R# setting nodes present in the specified document.
function Find-ReSharperSettingNodes ($doc) {
    # ReSharper setting nodes are located directly under the root node.
    # They are located within the namespace, so we filter nodes inside that namespace.
    $root = Get-ReSharperSettingsRootNode $doc

    return $root.ChildNodes.Where({$_.NodeType -eq "Element" -AND $_.NamespaceURI -eq "clr-namespace:System;assembly=mscorlib"})
}