<#
.SYNOPSIS

This script file is designed to deploy PackageManagementService to IIS.
.DESCRIPTION

The purpose of this script is to deploy PackageManagementService from WDP to IIS.
Prerequisites:
Application instance should exist on the IIS.
.EXAMPLE

PS> .\OnPremiseDeploy.ps1 -instanceName "myInstanceName" -wdpPackagePath "C:\deployment-package\PackageManagementServicePackage.x.y.z.rev-ddmmyy.wdp.zip"
.PARAMETER instanceName

The name of IIS application instance.
.PARAMETER wdpPackagePath

The path to the WDP .zip archive to deploy service from.
#>
param(
    [Parameter(Mandatory = $True)]
    [string]
    $instanceName,

    [Parameter(Mandatory = $True)]
    [string]
    $wdpPackagePath
)

Write-Host -BackgroundColor Cyan "Deploying PackageManagementService package to IIS ""$instanceName"" instance.";

[string]$msDeployPath = (get-childitem "HKLM:\SOFTWARE\Microsoft\IIS Extensions\MSDeploy" | Select-Object -last 1).GetValue("InstallPath");
[string]$msDeployExePath = Join-Path $msDeployPath "msdeploy.exe";

if (!(Test-Path $msDeployExePath)) {
    Write-Host "Unable to find msdeploy.exe, please refer the link to donwload and install it, link: https://www.iis.net/downloads/microsoft/web-deploy";
}

& $msDeployExePath -verb:sync -source:package=$wdpPackagePath -dest:iisApp=$instanceName

Write-Host -BackgroundColor Cyan "PackageManagementService has been successfully deployed to IIS ""$instanceName"" instance.";